@@ -1,3 +1,3 @@
 # ugo=rw,o=rx
-DEFAULT_UMASK = 0o0002
 DEFAULT_CHMOD_MODE = 0o775
+DEFAULT_UMASK = 0o777-DEFAULT_CHMOD_MODE
